# frozen_string_literal: true

require 'nokogiri'

module Jekyll
  module Filters
    module Nokogiri
      # Adds an attribute to all elements matching a CSS filter.
      #
      # @param input [String]
      # @param filter [String]
      # @param attribute [String]
      # @param value [Any]
      # @example
      #   {{ "<p>Hi</p>" | add_attribute: "p", "class", "lead" }}
      # @return [String]
      def add_attribute(input, filter, attribute, value)
        ::Nokogiri::HTML5.fragment(input).tap do |html_fragment|
          html_fragment.css(filter).each do |element|
            element[attribute] = value.to_s
          end
        end.to_s
      end
    end
  end
end
